<?php

    if ( ! defined( 'ABSPATH' ) ) :
        exit; // Exit if accessed directly
    endif;

    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // ReduxFramework  Config File
    // For full documentation, please visit: https://docs.reduxframework.com
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // This is your option name where all the Redux data is stored.
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

    $opt_name = "maxrank_theme_option";


    /**
     * SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => TRUE,
        // Show the sections below the admin menu item or not
        'menu_title'           => sprintf( esc_html__( '%s Options', 'maxrank' ), $theme->get( 'Name' ) ),
        'page_title'           => sprintf( esc_html__( '%s Theme Options', 'maxrank' ), $theme->get( 'Name' ) ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => FALSE,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => TRUE,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => TRUE,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-admin-generic',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => FALSE,
        // Show the time the page took to load, etc
        'update_notice'        => TRUE,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => TRUE,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => '40',
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => TRUE,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => FALSE,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => TRUE,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => TRUE,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => TRUE,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        'footer_credit'        => sprintf( esc_html__( '%s Theme Options', 'maxrank' ), $theme->get( 'Name' ) ),
        // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => TRUE,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => TRUE,
                'rounded' => FALSE,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // START SECTIONS
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

    // General Settings
    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-cogs',
        'title'  => esc_html__('General Settings', 'maxrank'),
        'fields' => array(
            array(
                'id'       => 'tt-breadcrumb',
                'type'     => 'switch',
                'title'    => esc_html__('Breadcrumb', 'maxrank'),
                'subtitle' => esc_html__('Show or Hide Your website Breadcrumb', 'maxrank'),
                'on'       => esc_html__('Show', 'maxrank'),
                'off'      => esc_html__('Hide', 'maxrank'),
                'default'  => TRUE,
            ),

            array(
                'id'       => 'smooth-scroll',
                'type'     => 'switch',
                'title'    => esc_html__('Smooth Page Scroll', 'maxrank'),
                'subtitle' => esc_html__('Enable or Disabled Smooth Page Scroll', 'maxrank'),
                'on'       => esc_html__('Enable', 'maxrank'),
                'off'      => esc_html__('Disabled', 'maxrank'),
                'default'  => TRUE,
            )
        )
    ));


    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Logo settings
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-slideshare',
        'title'  => esc_html__('Logo Settings', 'maxrank'),
        'fields' => array(
            array(
                'id'       => 'logo-type',
                'type'     => 'switch',
                'title'    => esc_html__('Logo Type', 'maxrank'),
                'subtitle' => esc_html__('You can set text or image logo', 'maxrank'),
                'on'       => esc_html__('Image Logo', 'maxrank'),
                'off'      => esc_html__('Text Logo', 'maxrank'),
                'default'  => TRUE,
            ),
            array(
                'id'       => 'text-logo',
                'type'     => 'text',
                'required' => array('logo-type', '=', '0'),
                'title'    => esc_html__('Logo Text', 'maxrank'),
                'subtitle' => esc_html__('Change your logo text', 'maxrank')
            ),
            array(
                'id'       => 'logo',
                'type'     => 'media',
                'preview'  => 'true',
                'required' => array('logo-type', '=', '1'),
                'title'    => esc_html__('Site Logo.', 'maxrank'),
                'subtitle' => esc_html__('Change Site logo dimension: 110px &times; 60px', 'maxrank')
            ),
            array(
                'id'       => 'retina-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'required' => array('logo-type', '=', '1'),
                'title'    => esc_html__('Retina Logo Image (High Density)', 'maxrank'),
                'subtitle' => esc_html__('Change Retina logo dimension: 296px &times; 160px', 'maxrank'),
                'desc'     => esc_html__('Add a 296px &times; 160px pixels image that will be used as the logo in the header section. For the Retina Logo Image the even number of pixels is less important because it will be hardly noticable', 'maxrank'),
            ),
            array(
                'id'       => 'mobile-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'required' => array('logo-type', '=', '1'),
                'title'    => esc_html__('Site Mobile Logo.', 'maxrank'),
                'subtitle' => esc_html__('Change site mobile logo dimension: 145px &times; 78px', 'maxrank')
            ),
            array(
                'id'       => 'retina-mobile-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'required' => array('logo-type', '=', '1'),
                'title'    => esc_html__('Retina Mobile Logo Image (High Density)', 'maxrank'),
                'subtitle' => esc_html__('Change retina mobile logo dimension: 296px &times; 160px', 'maxrank'),
                'desc'     => esc_html__('Add a 296px &times; 160px pixels image that will be used as the logo in the header section. For the Retina Logo Image the even number of pixels is less important because it will be hardly noticable', 'maxrank'),
            ),
            array(
                'id'       => 'sticky-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'required' => array('logo-type', '=', '1'),
                'title'    => esc_html__('Site Sticky Logo.', 'maxrank'),
                'subtitle' => esc_html__('Change site sticky logo dimension: 110px &times; 60px', 'maxrank')
            ),
            array(
                'id'       => 'retina-sticky-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'required' => array('logo-type', '=', '1'),
                'title'    => esc_html__('Retina Sticky Logo Image (High Density)', 'maxrank'),
                'subtitle' => esc_html__('Change retina sticky logo dimension: 296px &times; 160px', 'maxrank'),
                'desc'     => esc_html__('Add a 296px &times; 160px pixels image that will be used as the logo in the header section. For the Retina Logo Image the even number of pixels is less important because it will be hardly noticable', 'maxrank'),
            ),
            array(
                'id'       => 'sticky-mobile-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'required' => array('logo-type', '=', '1'),
                'title'    => esc_html__('Site Sticky Mobile Logo.', 'maxrank'),
                'subtitle' => esc_html__('Change site sticky mobile logo dimension: 145px &times; 78px', 'maxrank')
            ),
            array(
                'id'       => 'retina-sticky-mobile-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'required' => array('logo-type', '=', '1'),
                'title'    => esc_html__('Retina Sticky Mobile Logo Image (High Density)', 'maxrank'),
                'subtitle' => esc_html__('Change retina sticky mobile logo dimension: 296px &times; 160px', 'maxrank'),
                'desc'     => esc_html__('Add a 296px &times; 160px pixels image that will be used as the logo in the header section. For the Retina Logo Image the even number of pixels is less important because it will be hardly noticable', 'maxrank'),
            ),
            
            array(
                'id'             => 'logo-margin',
                'type'           => 'spacing',
                'output'         => array('.navbar-brand'),
                'mode'           => 'margin',
                'units'          => 'px',
                'units_extended' => 'false',
                'title'          => esc_html__('Logo Margin Option', 'maxrank'),
                'subtitle'       => esc_html__('You can change logo margin if needed.', 'maxrank'),
                'desc'           => esc_html__('Change top, right, bottom and left value in px, e.g: 10', 'maxrank')
            )
        )
    ));

    // Header settings
    Redux::setSection( $opt_name, array(
        'icon'   => 'el el-website',
        'title'  => esc_html__( 'Header Settings', 'maxrank' ),
        'fields' => array(
            
            array(
                'id'             => 'navbar-margin',
                'type'           => 'spacing',
                'output'         => array('.main-menu-wrapper'),
                'mode'           => 'margin',
                'units'          => 'px',
                'units_extended' => 'false',
                'title'          => esc_html__('Main menu margin option', 'maxrank'),
                'subtitle'       => esc_html__('You can change main menu margin if needed.', 'maxrank'),
                'desc'           => esc_html__('Change top, right, bottom and left value in px, e.g: 10', 'maxrank')
            ),

            array(
                'id'             => 'navbar-height',
                'type'           => 'spacing',
                'output'         => array('.main-menu-wrapper'),
                'mode'           => 'padding',
                'units'          => 'px',
                'units_extended' => 'false',
                'title'          => esc_html__('Main menu padding option', 'maxrank'),
                'subtitle'       => esc_html__('You can change main menu padding if needed.', 'maxrank'),
                'desc'           => esc_html__('Change top, right, bottom and left value in px, e.g: 10', 'maxrank')
            ),

            // menu background color
            array(
                'id'       => 'menu-bg-color',
                'type'     => 'color',
                'title'    => esc_html__( 'Menu background color', 'maxrank' ),
                'subtitle' => esc_html__( 'Pick color for menu background.', 'maxrank' )
            ),

            // menu color
            array(
                'id'       => 'menu-color',
                'type'     => 'color',
                'title'    => esc_html__( 'Menu font color', 'maxrank' ),
                'subtitle' => esc_html__( 'Pick color for menu.', 'maxrank' )
            ),

            // menu hover color
            array(
                'id'       => 'menu-hover-color',
                'type'     => 'color',
                'title'    => esc_html__( 'Menu hover font color', 'maxrank' ),
                'subtitle' => esc_html__( 'Pick color for menu hover.', 'maxrank' )
            ),

            // mobile menu background color
            array(
                'id'       => 'mobile-menu-bg-color',
                'type'     => 'color',
                'title'    => esc_html__( 'Mobile menu background color', 'maxrank' ),
                'subtitle' => esc_html__( 'Pick color for mobile menu background.', 'maxrank' )
            ),

            // mobile menu color
            array(
                'id'       => 'mobile-menu-color',
                'type'     => 'color',
                'title'    => esc_html__( 'Mobile menu font color', 'maxrank' ),
                'subtitle' => esc_html__( 'Pick color for mobile menu.', 'maxrank' )
            ),

            // sticky menu visibility
            array(
                'id'       => 'sticky-menu-visibility',
                'type'     => 'switch',
                'title'    => esc_html__('Sticky menu visibility', 'maxrank'),
                'subtitle' => esc_html__('Visible or Hidden sticky menu', 'maxrank'),
                'on'       => esc_html__('Visible', 'maxrank'),
                'off'      => esc_html__('Hidden', 'maxrank'),
                'default'  => TRUE,
            ),

            // sticky menu background color
            array(
                'id'       => 'sticky-menu-bg-color',
                'type'     => 'color',
                'required' => array('sticky-menu-visibility', '=', '1'),
                'title'    => esc_html__( 'Sticky menu background color', 'maxrank' ),
                'subtitle' => esc_html__( 'Pick color for sticky menu background.', 'maxrank' )
            ),

            // sticky menu color
            array(
                'id'       => 'sticky-menu-color',
                'type'     => 'color',
                'required' => array('sticky-menu-visibility', '=', '1'),
                'title'    => esc_html__( 'Sticky menu font color', 'maxrank' ),
                'subtitle' => esc_html__( 'Pick color for sticky menu.', 'maxrank' )
            ),
			

            // header top wrapper
            array(
                'id'       => 'header-top-visibility',
                'type'     => 'switch',
                'title'    => esc_html__('Header topbar visibility', 'maxrank'),
                'subtitle' => esc_html__('Visible or Hidden header topbar', 'maxrank'),
                'on'       => esc_html__('Visible', 'maxrank'),
                'off'      => esc_html__('Hidden', 'maxrank'),
                'default'  => TRUE,
            ),

            array(
                'id'       => 'header-contact',
                'type'     => 'text',
                'required' => array('header-top-visibility', '=', '1'),
                'title'    => esc_html__('Header contact Number', 'maxrank'),
                'subtitle' => esc_html__('Change header contact number', 'maxrank'),
                'default'  => '(+89) 123 445 6789'
            ),

            array(
                'id'       => 'header-mail',
                'type'     => 'text',
                'required' => array('header-top-visibility', '=', '1'),
                'title'    => esc_html__('Header Email', 'maxrank'),
                'subtitle' => esc_html__('Change header email', 'maxrank'),
                'default'  => 'hello@address.net'
            ),

            array(
                'id'       => 'header-social-button',
                'type'     => 'switch',
                'required' => array('header-top-visibility', '=', '1'),
                'title'    => esc_html__('Header social button visibility', 'maxrank'),
                'subtitle' => esc_html__('Visible or Hidden header social button', 'maxrank'),
                'on'       => esc_html__('Visible', 'maxrank'),
                'off'      => esc_html__('Hidden', 'maxrank'),
                'default'  => TRUE,
            ),
			
            //header SEO button
           
            array(
                'id'       => 'header-seo-btn-visibility',
                'type'     => 'switch',
                'title'    => esc_html__('Header SEO button visibility', 'maxrank'),
                'subtitle' => esc_html__('Visible or Hidden header SEO Button', 'maxrank'),
                'on'       => esc_html__('Visible', 'maxrank'),
                'off'      => esc_html__('Hidden', 'maxrank'),
                'default'  => TRUE,
            ),

			//header SEO button
           
			array(
                'id'       => 'header-search-btn-visibility',
                'type'     => 'switch',
                'title'    => esc_html__('Header Search button visibility', 'maxrank'),
                'subtitle' => esc_html__('Visible or Hidden header Search Button', 'maxrank'),
                'on'       => esc_html__('Visible', 'maxrank'),
                'off'      => esc_html__('Hidden', 'maxrank'),
                'default'  => TRUE,
            ),

            
            array(
                'id'       => 'header-seo-btn-text',
                'type'     => 'text',
                'required' => array('header-seo-btn-visibility', '=', '1'),
                'title'    => esc_html__('SEO Button Text', 'maxrank'),
                'subtitle' => esc_html__('Put SEO button text', 'maxrank'),
                'default'  => esc_html__('Free SEO analysis', 'maxrank')
            ),

			array(
                'id'       => 'header-seo-btn-color',
                'type'     => 'color',
                'required' => array('header-seo-btn-visibility', '=', '1'),
                'title'    => esc_html__('SEO Button Background Color', 'maxrank'),
                'subtitle' => esc_html__('Choose SEO button background color', 'maxrank')
            ),

			 array(
                'id'       => 'header-seo-btn-link',
                'type'     => 'text',
                'required' => array('header-seo-btn-visibility', '=', '1'),
                'title'    => esc_html__('SEO Button Link', 'maxrank'),
                'subtitle' => esc_html__('Put SEO button url', 'maxrank'),
				'default' => '#'
            ),
			
        )
    ));


    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Page header image settings
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-picture',
        'title'  => esc_html__('Page Header Image', 'maxrank'),
        'fields' => array(

            array(
                'id'       => 'page-header-image',
                'type'     => 'media',
                'preview'  => 'true',
                'title'    => esc_html__('Page Header Background.', 'maxrank'),
                'desc'     => esc_html__('Upload image from media library, dimension: 1920px x 450px', 'maxrank')
            ),
            array(
                'id'       => 'portfolio-header-image',
                'type'     => 'media',
                'preview'  => 'true',
                'title'    => esc_html__('portfolio Header Background.', 'maxrank'),
                'desc'     => esc_html__('Upload image from media library, dimension: 1920px x 450px', 'maxrank')
            ),
            array(
                'id'       => 'blog-header-image',
                'type'     => 'media',
                'preview'  => 'true',
                'title'    => esc_html__('Blog Header Background.', 'maxrank'),
                'desc'     => esc_html__('Upload image from media library, dimension: 1920px x 450px', 'maxrank')
            ),
            array(
                'id'       => 'author-header-image',
                'type'     => 'media',
                'preview'  => 'true',
                'title'    => esc_html__('Author Header Background.', 'maxrank'),
                'desc'     => esc_html__('Upload image from media library, dimension: 1920px x 450px', 'maxrank')
            ),
            array(
                'id'       => 'category-header-image',
                'type'     => 'media',
                'preview'  => 'true',
                'title'    => esc_html__('Category Header Background.', 'maxrank'),
                'desc'     => esc_html__('Upload image from media library, dimension: 1920px x 450px', 'maxrank')
            ),
            array(
                'id'       => 'tag-header-image',
                'type'     => 'media',
                'preview'  => 'true',
                'title'    => esc_html__('Tag Header Background.', 'maxrank'),
                'desc'     => esc_html__('Upload image from media library, dimension: 1920px x 450px', 'maxrank')
            ),
            array(
                'id'       => 'search-header-image',
                'type'     => 'media',
                'preview'  => 'true',
                'title'    => esc_html__('Search Header Background.', 'maxrank'),
                'desc'     => esc_html__('Upload image from media library, dimension: 1920px x 450px', 'maxrank')
            ),
            array(
                'id'       => 'archive-header-image',
                'type'     => 'media',
                'preview'  => 'true',
                'title'    => esc_html__('Archive Header Background.', 'maxrank'),
                'desc'     => esc_html__('Upload image from media library, dimension: 1920px x 450px', 'maxrank')
            )
        )
    ));

    
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Presets settings
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-brush',
        'title'  => esc_html__('Preset color', 'maxrank'),
        'fields' => array(
            
            array(
                'id'       => 'accent-color',
                'type'     => 'color',
                'title'    => esc_html__( 'Site Accent Color', 'maxrank' ),
                'subtitle' => esc_html__( 'Pick color for the theme accent color (default: #FF6600).', 'maxrank' ),
                'default'  => '#FF6600',
            ),

            array(
                'id'       => 'link-color',
                'type'     => 'color',
                'title'    => esc_html__( 'Site Link Color', 'maxrank' ),
                'subtitle' => esc_html__( 'Pick color for all link (default: #ff6600).', 'maxrank' ),
                'default'  => '#ff6600',
            )
        )
    ));


    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Typography
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-font',
        'title'  => esc_html__('Typography', 'maxrank'),
        'fields' => array(
            
            // body typography
            array(
                'id'       => 'body-typography',
                'type'     => 'typography',
                'title'    => esc_html__( 'Body Font', 'maxrank' ),
                'subtitle' => esc_html__( 'Specify the body font properties.', 'maxrank' ),
                'google'   => true,
                'all_styles' => true,
                'text-align' => false,
                'default'  => array(
                    'color'       => '#666',
                    'font-size'   => '18px',
                    'font-family' => 'Lato',
                    'font-weight' => '400',
                    'line-height' => '30px'
                ),
            ),

            // menu typography
            array(
                'id'       => 'menu-typography',
                'type'     => 'typography',
                'title'    => esc_html__( 'Menu Font', 'maxrank' ),
                'subtitle' => esc_html__( 'Specify the menu font properties.', 'maxrank' ),
                'google'   => true,
                'all_styles' => true,
                'text-align' => false,
                'color'     => false,
                'default'  => array(
                    'font-size'   => '17px',
                    'font-family' => 'Lato',
                    'font-weight' => '400',
                    'line-height' => '20px'
                ),
            ),

            // Heading all typography
            array(
                'id'       => 'heading-typography',
                'type'     => 'typography',
                'title'    => esc_html__( 'Heading Font', 'maxrank' ),
                'subtitle' => esc_html__( 'This settings for all heading font (h1, h2, h3, h4, h5, h6)', 'maxrank' ),
                'google'   => true,
                'all_styles' => true,
                'text-align' => false,
                'font-size' => false,
                'line-height' => false,
                'default'  => array(
                    'color'       => '#212121',
                    'font-family' => 'PT Serif',
                    'font-weight' => '700',
                ),
            ),

            // only H1 typography
            array(
                'id'       => 'h1-typography',
                'type'     => 'typography',
                'title'    => esc_html__( 'H1 (Heading one)', 'maxrank' ),
                'subtitle' => esc_html__( 'This settings only for H1', 'maxrank' ),
                'font-family' => false,
                'google'   => false,
                'text-align' => false,
                'font-size' => true,
                'line-height' => true,
                'color' => false,
                'font-weight' => false,
                'font-style' => false,
                'default'  => array(
                    'font-size'   => '70px',
                    'line-height' => '80px'
                ),
            ),

            // only H2 typography
            array(
                'id'       => 'h2-typography',
                'type'     => 'typography',
                'title'    => esc_html__( 'H2 (Heading two)', 'maxrank' ),
                'subtitle' => esc_html__( 'This settings only for H2', 'maxrank' ),
                'font-family' => false,
                'google'   => false,
                'text-align' => false,
                'font-size' => true,
                'line-height' => true,
                'color' => false,
                'font-weight' => false,
                'font-style' => false,
                'default'  => array(
                    'font-size'   => '35px',
                    'line-height' => '40px'
                ),
            ),

            // only H3 typography
            array(
                'id'       => 'h3-typography',
                'type'     => 'typography',
                'title'    => esc_html__( 'H3 (Heading three)', 'maxrank' ),
                'subtitle' => esc_html__( 'This settings only for H3', 'maxrank' ),
                'font-family' => false,
                'google'   => false,
                'text-align' => false,
                'font-size' => true,
                'line-height' => true,
                'color' => false,
                'font-weight' => false,
                'font-style' => false,
                'default'  => array(
                    'font-size'   => '24px',
                    'line-height' => '30px'
                ),
            ),

            // only H4 typography
            array(
                'id'       => 'h4-typography',
                'type'     => 'typography',
                'title'    => esc_html__( 'H4 (Heading four)', 'maxrank' ),
                'subtitle' => esc_html__( 'This settings only for H4', 'maxrank' ),
                'font-family' => false,
                'google'   => false,
                'text-align' => false,
                'font-size' => true,
                'line-height' => true,
                'color' => false,
                'font-weight' => false,
                'font-style' => false,
                'default'  => array(
                    'font-size'   => '20px',
                    'line-height' => '27px'
                ),
            ),

            // only H5 typography
            array(
                'id'       => 'h5-typography',
                'type'     => 'typography',
                'title'    => esc_html__( 'H5 (Heading five)', 'maxrank' ),
                'subtitle' => esc_html__( 'This settings only for H5', 'maxrank' ),
                'font-family' => false,
                'google'   => false,
                'text-align' => false,
                'font-size' => true,
                'line-height' => true,
                'color' => false,
                'font-weight' => false,
                'font-style' => false,
                'default'  => array(
                    'font-size'   => '18px',
                    'line-height' => '25px'
                ),
            ),

            // only H6 typography
            array(
                'id'       => 'h6-typography',
                'type'     => 'typography',
                'title'    => esc_html__( 'H6 (Heading six)', 'maxrank' ),
                'subtitle' => esc_html__( 'This settings only for H6', 'maxrank' ),
                'font-family' => false,
                'google'   => false,
                'text-align' => false,
                'font-size' => true,
                'line-height' => true,
                'color' => false,
                'font-weight' => false,
                'font-style' => false,
                'default'  => array(
                    'font-size'   => '16px',
                    'line-height' => '22px'
                )
            )

        )
    ));


    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Blog settings
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    
    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-file-edit',
        'title'  => esc_html__('Blog Settings', 'maxrank'),
        'fields' => array(

            array(
                'id'       => 'blog-title',
                'type'     => 'text',
                'title'    => esc_html__('Blog Page Title', 'maxrank'),
                'subtitle' => esc_html__('Enter Blog page title here, if leave blank then site title will appear', 'maxrank')
            ),

            array(
                'id'       => 'blog-sidebar',
                'type'     => 'image_select',
                'title'    => esc_html__('Blog sidebar setting', 'maxrank'),
                'subtitle' => esc_html__('Select blog sidebar', 'maxrank'),
                'options'  => array(
                    'no-sidebar'    => array(
                        'alt' => 'No sidebar',
                        'img' => ReduxFramework::$_url . 'assets/img/1col.png'
                    ),
                    'left-sidebar'  => array(
                        'alt' => 'Left sidebar',
                        'img' => ReduxFramework::$_url . 'assets/img/2cl.png'
                    ),
                    'right-sidebar' => array(
                        'alt' => 'Right sidebar',
                        'img' => ReduxFramework::$_url . 'assets/img/2cr.png'
                    )
                ),
                'default'  => 'right-sidebar'
            ),

            array(
                'id'       => 'tt-post-meta',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Post meta options', 'maxrank' ),
                'subtitle' => esc_html__( 'Check to show post meta', 'maxrank' ),
                'options'  => array(
                    'post-date'         => esc_html__( 'Post Date', 'maxrank' ),
                    'post-author'       => esc_html__( 'Post Author', 'maxrank' ),
                    'post-category'     => esc_html__( 'Post Category', 'maxrank' ),
                    'post-comment'      => esc_html__( 'Post Comment', 'maxrank' ),
                ),
                'default'  => array(
                    'post-date' => '1',
                    'post-author'  => '1',
                    'post-category'   => '1',
                    'post-comment' => '0',
                )
            ),

            array(
                'id'       => 'show-admin-info',
                'type'     => 'switch',
                'title'    => esc_html__('Show Admin Info', 'maxrank'),
                'subtitle' => esc_html__('Show or hide admin info', 'maxrank'),
                'on'       => esc_html__('Show', 'maxrank'),
                'off'      => esc_html__('Hide', 'maxrank'),
                'default'  => TRUE
            ),

            array(
                'id'       => 'single-post-navigation',
                'type'     => 'switch',
                'title'    => esc_html__('Single post navigation', 'maxrank'),
                'subtitle' => esc_html__('Show or hide post navigation', 'maxrank'),
                'on'       => esc_html__('Show', 'maxrank'),
                'off'      => esc_html__('Hide', 'maxrank'),
                'default'  => TRUE
            ),

            array(
                'id'       => 'blog-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'title'    => esc_html__('Blog Logo.', 'maxrank'),
                'subtitle' => esc_html__('This logo option only for blog related page, logo dimension: 145px &times; 55px', 'maxrank')
            ),

            array(
                'id'       => 'blog-mobile-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'title'    => esc_html__('Blog Mobile Logo.', 'maxrank'),
                'subtitle' => esc_html__('This logo option only for blog related page,logo dimension: 145px &times; 55px', 'maxrank')
            ),

            array(
                'id'       => 'blog-sticky-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'title'    => esc_html__('Blog Sticky Logo.', 'maxrank'),
                'subtitle' => esc_html__('This logo option only for blog related page,logo dimension: 145px &times; 55px', 'maxrank')
            ),

            array(
                'id'       => 'blog-sticky-mobile-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'title'    => esc_html__('Blog Sticky Mobile Logo.', 'maxrank'),
                'subtitle' => esc_html__('This logo option only for blog related page,logo dimension: 145px &times; 55px', 'maxrank')
            )
        )
    ));


    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Page settings
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-file-edit',
        'title'  => esc_html__('Page Settings', 'maxrank'),
        'fields' => array(

            array(
                'id'       => 'page-sidebar',
                'type'     => 'image_select',
                'title'    => esc_html__('Page Sidebar', 'maxrank'),
                'subtitle' => esc_html__('Select page sidebar', 'maxrank'),
                'options'  => array(
                    'no-sidebar'    => array(
                        'alt' => 'No sidebar',
                        'img' => ReduxFramework::$_url . 'assets/img/1col.png'
                    ),
                    'left-sidebar'  => array(
                        'alt' => 'Left sidebar',
                        'img' => ReduxFramework::$_url . 'assets/img/2cl.png'
                    ),
                    'right-sidebar' => array(
                        'alt' => 'Right sidebar',
                        'img' => ReduxFramework::$_url . 'assets/img/2cr.png'
                    )
                ),
                'default'  => 'right-sidebar'
            ),

            array(
                'id'       => 'page-comment-visibility',
                'type'     => 'switch',
                'title'    => esc_html__('Page comment visibility', 'maxrank'),
                'subtitle' => esc_html__('Show or hide page comment globally', 'maxrank'),
                'on'       => esc_html__('Visible', 'maxrank'),
                'off'      => esc_html__('Hidden', 'maxrank'),
                'default'  => FALSE,
            )
        )
    ));


    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Portfolio settings
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-th-large',
        'title'  => esc_html__('Portfolio Settings', 'maxrank'),
        'fields' => array(
            array(
                'id'       => 'portfolio-page-title',
                'type'     => 'text',
                'title'    => esc_html__('Portfolio Title', 'maxrank'),
                'subtitle' => esc_html__('You can change portfolio title', 'maxrank'),
                'default'  => 'Lets Everyone Know Why We Are The best',
            ),
            array(
                'id'       => 'portfolio-page-sub-title',
                'type'     => 'text',
                'title'    => esc_html__('Portfolio Sub-Title', 'maxrank'),
                'subtitle' => esc_html__('You can change portfolio sub-title', 'maxrank'),
                'default'  => 'Synergistically productivate mission critical materials whereas cross media sources. Seamlessly visualize methodologies cross media sources without.',
            ),

            array(
                'id' => 'portfolio-per-page',
                'type' => 'slider',
                'title' => esc_html__('Portfolio per page', 'maxrank'),
                'subtitle' => esc_html__('How many portfolio you want to show per page', 'maxrank'),
                'desc' => esc_html__('Portfolio description. Min: 3, max: 60, step: 3, default value: 6', 'maxrank'),
                "default" => 6,
                "min" => 3,
                "step" => 3,
                "max" => 60,
                'display_value' => 'text'
            )
        )
    ));

  
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Preloader settings
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-repeat-alt',
        'title'  => esc_html__('Preloader Settings', 'maxrank'),
        'fields' => array(
            array(
                'id'       => 'page-preloader',
                'type'     => 'switch',
                'title'    => esc_html__('Page Preloader', 'maxrank'),
                'subtitle' => esc_html__('You can enable or disable page preloader from here.', 'maxrank'),
                'on'       => esc_html__('Enable', 'maxrank'),
                'off'      => esc_html__('Disable', 'maxrank'),
                'default'  => TRUE,
            ),

            array(
                'id'       => 'loader-bg-color',
                'type'     => 'color',
                'required' => array( 'page-preloader', '=', '1' ),
                'title'    => esc_html__( 'Preloader background color', 'maxrank' ),
                'subtitle' => esc_html__( 'Pick color for preloader background (default: #ffffff).', 'maxrank' ),
                'default'  => '#ffffff',
            ),

            array(
                'id'       => 'tt-loader',
                'type'     => 'media',
                'preview'  => 'true',
                'required' => array( 'page-preloader', '=', '1' ),
                'title'    => esc_html__('Animation file', 'maxrank'),
                'subtitle' => esc_html__('Upload loader gif animation file', 'maxrank')
            )
        )
    ));
    

	//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Social icon settings
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-facebook',
        'title'  => esc_html__('Topbar Social Icon', 'maxrank'),
        'fields' => array(
            
            array(
                'id'       => 'social-icon-visibility',
                'type'     => 'switch',
                'title'    => esc_html__('Social icon visibility', 'maxrank'),
                'subtitle' => esc_html__('Shor or hide social icon from footer', 'maxrank'),
                'on'       => esc_html__('Show', 'maxrank'),
                'off'      => esc_html__('Hide', 'maxrank'),
                'default'  => TRUE,
            ),

            array(
                'id'       => 'facebook-link',
                'type'     => 'text',
                'required' => array('social-icon-visibility', '=', '1'),
                'title'    => esc_html__('Facebook Link', 'maxrank'),
                'subtitle' => esc_html__('Enter facebook page or profile link. Leave blank to hide icon.', 'maxrank'),
                'default'  => "#"
            ),
            array(
                'id'       => 'twitter-link',
                'type'     => 'text',
                'required' => array('social-icon-visibility', '=', '1'),
                'title'    => esc_html__('Twitter Link', 'maxrank'),
                'subtitle' => esc_html__('Enter twitter link. Leave blank to hide icon.', 'maxrank'),
                'default'  => "#"
            ),
            array(
                'id'       => 'google-plus-link',
                'type'     => 'text',
                'required' => array('social-icon-visibility', '=', '1'),
                'title'    => esc_html__('Google Plus Link', 'maxrank'),
                'subtitle' => esc_html__('Enter google plus page or profile link. Leave blank to hide icon.', 'maxrank'),
                'default'  => "#"
            ),
            array(
                'id'       => 'youtube-link',
                'type'     => 'text',
                'required' => array('social-icon-visibility', '=', '1'),
                'title'    => esc_html__('Youtube Link', 'maxrank'),
                'subtitle' => esc_html__('Enter youtube chanel link. Leave blank to hide icon.', 'maxrank'),
            ),
            array(
                'id'       => 'pinterest-link',
                'type'     => 'text',
                'required' => array('social-icon-visibility', '=', '1'),
                'title'    => esc_html__('Pinterest Link', 'maxrank'),
                'subtitle' => esc_html__('Enter pinterest link. Leave blank to hide icon.', 'maxrank'),
                'default'  => "#"
            ),
            array(
                'id'       => 'flickr-link',
                'type'     => 'text',
                'required' => array('social-icon-visibility', '=', '1'),
                'title'    => esc_html__('Flickr Link', 'maxrank'),
                'subtitle' => esc_html__('Enter flicker link. Leave blank to hide icon.', 'maxrank'),
            ),
            array(
                'id'       => 'linkedin-link',
                'type'     => 'text',
                'required' => array('social-icon-visibility', '=', '1'),
                'title'    => esc_html__('Linkedin Link', 'maxrank'),
                'subtitle' => esc_html__('Enter linkedin profile link. Leave blank to hide icon.', 'maxrank'),
            ),
            array(
                'id'       => 'vimeo-link',
                'type'     => 'text',
                'required' => array('social-icon-visibility', '=', '1'),
                'title'    => esc_html__('Vimeo Link', 'maxrank'),
                'subtitle' => esc_html__('Enter vimeo chanel link. Leave blank to hide icon.', 'maxrank'),
            ),
            array(
                'id'       => 'instagram-link',
                'type'     => 'text',
                'required' => array('social-icon-visibility', '=', '1'),
                'title'    => esc_html__('Instagram Link', 'maxrank'),
                'subtitle' => esc_html__('Enter instagram page or profile link. Leave blank to hide icon.', 'maxrank'),
            ),
            array(
                'id'       => 'dribbble-link',
                'type'     => 'text',
                'required' => array('social-icon-visibility', '=', '1'),
                'title'    => esc_html__('Dribbble Link', 'maxrank'),
                'subtitle' => esc_html__('Enter dribbble profile link. Leave blank to hide icon.', 'maxrank'),
            ),
            array(
                'id'       => 'behance-link',
                'type'     => 'text',
                'required' => array('social-icon-visibility', '=', '1'),
                'title'    => esc_html__('Behance Link', 'maxrank'),
                'subtitle' => esc_html__('Enter behance profile link. Leave blank to hide icon.', 'maxrank'),
            ),
        )
    ));
	
	
	   
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Footer settings
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

    Redux::setSection( $opt_name, array(
        'icon'      => 'el-icon-photo',
        'customizer_width' => '450px',
        'title'     => esc_html__('Footer Settings', 'maxrank')
    ));
        
        
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Footer top settings
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-photo',
        'title'  => esc_html__('Footer Top Settings', 'maxrank'),
        'subsection' => true,
        'fields' => array(
            // footer style
            array(
                'id'       => 'footer-visibility',
                'type'     => 'switch',
                'title'    => esc_html__('Footer Top Visibility', 'maxrank'),
                'subtitle' => esc_html__('You can enable or disable Footer Top Section.', 'maxrank'),
                'on'       => esc_html__('Enable', 'maxrank'),
                'off'      => esc_html__('Disable', 'maxrank'),
                'default'  => TRUE,
            ),
            array(
                'id'       => 'footer-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'required' => array('footer-visibility', '=', '1'),
                'title'    => esc_html__('Footer Logo.', 'maxrank'),
                'subtitle' => esc_html__('Change footer logo dimension: 150px &times; 30px', 'maxrank'),
                'default' => 'http://www.facebook.com'
            ),
            array(
                'id'       => 'footer-retina-logo',
                'type'     => 'media',
                'preview'  => 'true',
                'required' => array('footer-visibility', '=', '1'),
                'title'    => esc_html__('Footer Retina Logo (High Density)', 'maxrank'),
                'subtitle' => esc_html__('Change Footer Retina logo dimension: 300px &times; 600px', 'maxrank'),
                'desc'     => esc_html__('Add a 300px &times; 60px pixels image that will be used as the logo in the header section. For the Retina Logo Image the even number of pixels is less important because it will be hardly noticable', 'maxrank'),
            ),
            array(
                'id'       => 'footer-about-text',
                'type'     => 'editor',
                'required' => array('footer-visibility', '=', array('1')),
                'title'    => esc_html__('Footer About Text', 'maxrank'),
                'subtitle' => esc_html__('Write footer about text here.', 'maxrank'),
                'default' => esc_html__('Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius.', 'maxrank')
            ),
            
            //learn more btn
            array(
                'id'       => 'footer-learn-more-btn-visibility',
                'type'     => 'switch',
                'required' => array('footer-visibility', '=', array('1')),
                'title'    => esc_html__('Learn More Button', 'maxrank'),
                'subtitle' => esc_html__('You can enable or disable learn more button.', 'maxrank'),
                'on'       => esc_html__('Enable', 'maxrank'),
                'off'      => esc_html__('Disable', 'maxrank'),
                'default'  => TRUE,
            ),
            array(
                'id'       => 'footer-learn-more-button-text',
                'type'     => 'text',
                'required' => array('footer-learn-more-btn-visibility', '=', array('1')),
                'title'    => esc_html__('Footer Learn more button text', 'maxrank'),
                'default' => 'Learn More About Max Rank'
            ),
            array(
                'id'       => 'footer-learn-more-button-link',
                'type'     => 'text',
                'required' => array('footer-learn-more-btn-visibility', '=', array('1')),
                'title'    => esc_html__('Footer Learn more button link', 'maxrank'),
            ),
            array(
                'id'       => 'footer-bg-color',
                'type'     => 'color',
                'required' => array('footer-learn-more-btn-visibility', '=', array('1')),
                'title'    => esc_html__('Footer background color', 'maxrank'),
                'default' => '#121921'
            ),
            
        )
    ));
    
    
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Footer copyright settings
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-photo',
        'title'  => esc_html__('Footer Copyright Settings', 'maxrank'),
        'subsection' => true,
        'fields' => array(
            
             // footer copyright style
            array(
                'id'       => 'footer-copyright-visibility',
                'type'     => 'switch',
                'title'    => esc_html__('Page Copyright Visibility', 'maxrank'),
                'subtitle' => esc_html__('You can enable or disable Copyright Section.', 'maxrank'),
                'on'       => esc_html__('Enable', 'maxrank'),
                'off'      => esc_html__('Disable', 'maxrank'),
                'default'  => TRUE,
            ),
            array(
                'id'       => 'footer-copyright-text',
                'type'     => 'editor',
                'required' => array('footer-copyright-visibility', '=', array('1')),
                'title'    => esc_html__('Footer Copyright Text', 'maxrank'),
                'subtitle' => esc_html__('Write footer copyright text here.', 'maxrank'),
                'default' => wp_kses('Copyright &copy; 2017 <a href="#">MaxRank</a><br/>Proudly Designed &amp; Developed  by <a href="#">TrendyTheme</a>', 
                    array(  
                        'a'          => array(
                            'href'   => array(),
                            'title'  => array(),
                            'target' => array()
                        ),
                        'b'     => array(),
                        'br'     => array(),
                        'em'     => array(),
                        'strong' => array(),
                        'ul'     => array(),
                        'li'     => array(),
                        'del'      => array(),
                        'p'      => array(),
                        'span'   => array(
                            'class' => array()
                        )
                    ))
            ),
            
        )
    ));
    
    
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    // Footer other settings
    //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
    Redux::setSection( $opt_name, array(
        'icon'   => 'el-icon-photo',
        'title'  => esc_html__('Footer Other Settings', 'maxrank'),
        'subsection' => true,
        'fields' => array(
            
            // bottom to top button visibility
            array(
                'id'       => 'footer-bottom-to-top-button',
                'type'     => 'switch',
                'title'    => esc_html__('Bottom To Top Button', 'maxrank'),
                'subtitle' => esc_html__('You can enable or disable Bottom to Top Button.', 'maxrank'),
                'on'       => esc_html__('Enable', 'maxrank'),
                'off'      => esc_html__('Disable', 'maxrank'),
                'default'  => TRUE,
            ),
            
            array(
                'id'       => 'footer-border-info',
                'type'     => 'info', 
                'style' => 'warning',
                'title'    => esc_html__('<b>Footer Border style</b>', 'maxrank'),
            ),
            
            // footer border setting
            array(
                'id'       => 'footer-border-visibility',
                'type'     => 'switch',
                'title'    => esc_html__('Footer top border setting', 'maxrank'),
                'subtitle' => esc_html__('You can enable or disable footer border.', 'maxrank'),
                'on'       => esc_html__('Enable', 'maxrank'),
                'off'      => esc_html__('Disable', 'maxrank'),
                'default'  => TRUE,
            ),
            
            array(
                'id'       => 'footer-border-theme',
                'type'     => 'radio',
                'required' => array('footer-border-visibility', '=', array('1')),
                'title'    => esc_html__('Choose footer border style', 'maxrank'), 
                'subtitle' => esc_html__('There are two diffrent border style. You can choose any one.', 'maxrank'),
                'options'  => array(
                    '1' => 'One color border', 
                    '2' => 'Multi color border', 
                ),
                'default' => '2'
            ),
            
            array(
                'id'       => 'footer-top-border',
                'type'     => 'border',
                'title'    => esc_html__( 'Footer Top Border', 'maxrank' ),
                'required' => array('footer-border-theme', '=', '1'),
                'default'  => array(
                    'border-color'  => '#f99800',
                    'border-style'  => 'solid',
                    'border-top'    => '3px',
                )
            ),
            
            array(
                'id'       => 'footer-border-height',
                'type'     => 'spinner', 
                'title'    => esc_html__('Border height', 'maxrank'),
                'subtitle'    => esc_html__('Enter border height by px', 'maxrank'),
                'default'  => '5',
                'min'      => '1',
                'step'     => '1',
                'max'      => '20',
                'required' => array('footer-border-theme', '=', '2'),
            ),
            
            array(
                'id'       => 'first-border-color',
                'type'     => 'color',
                'title'    => esc_html__('1st 20% Border color', 'maxrank'), 
                'desc' => esc_html__('Pick a color for the 1st 20% of border (default: #F99800).', 'maxrank'),
                'default'  => '#F99800',
                'required' => array('footer-border-theme', '=', '2'),
                'validate' => 'color',
            ),
            
            array(
                'id'       => 'second-border-color',
                'type'     => 'color',
                'title'    => esc_html__('2nd 20% Border color', 'maxrank'), 
                'desc' => esc_html__('Pick a color for the 2nd 20% of border (default: #F05924).', 'maxrank'),
                'default'  => '#F05924',
                'required' => array('footer-border-theme', '=', '2'),
                'validate' => 'color',
            ),
            
            array(
                'id'       => 'third-border-color',
                'type'     => 'color',
                'title'    => esc_html__('3rd 20% Border color', 'maxrank'), 
                'desc' => esc_html__('Pick a color for the 3rd 20% of border (default: #59AAE2).', 'maxrank'),
                'default'  => '#59AAE2',
                'required' => array('footer-border-theme', '=', '2'),
                'validate' => 'color',
            ),
            
            array(
                'id'       => 'fourth-border-color',
                'type'     => 'color',
                'title'    => esc_html__('4th 20% Border color', 'maxrank'), 
                'desc' => esc_html__('Pick a color for the 4th 20% of border (default: #F89101).', 'maxrank'),
                'default'  => '#F89101',
                'required' => array('footer-border-theme', '=', '2'),
                'validate' => 'color',
            ),
            
            array(
                'id'       => 'fifth-border-color',
                'type'     => 'color',
                'title'    => esc_html__('5th 20% Border color', 'maxrank'), 
                'desc' => esc_html__('Pick a color for the 5th 20% of border (default: #FF3133).', 'maxrank'),
                'default'  => '#FF3133',
                'required' => array('footer-border-theme', '=', '2'),
                'validate' => 'color',
            )
        )
    ));
    

    /*
     * <--- END SECTIONS
     */