<?php

if ( ! defined( 'ABSPATH' ) ) :
    exit; // Exit if accessed directly
endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Adds custom classes to the array of body classes.
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'maxrank_body_classes' ) ) :

	function maxrank_body_classes( $classes ) {
		
		if (function_exists('rwmb_meta')) :
			$header_page_topbar = rwmb_meta('maxrank_header_topbar');
			$header_option = maxrank_option('header-top-visibility', false, false);

			if ($header_page_topbar == 'header-topbar-show' || $header_page_topbar == 'inherit-theme-option' && $header_option == true) :
				$classes[] = 'has-header-topbar';
			endif;
		endif;

		if (maxrank_option('search-visibility', false, true)) :
			$classes[] = 'has-header-search';
		endif;

		$classes[] = maxrank_option('footer-style', false, 'footer-multipage');

		// Adds a class of group-blog to blogs with more than 1 published author.
		if ( is_multi_author() ) :
			$classes[ ] = 'group-blog';
		endif;

		if (!is_page() && !is_singular('tt-portfolio') && !is_singular('tt-member')) :
			if(maxrank_option('blog-logo', 'url')){
				$classes[] = 'has-site-logo';
			}
			if(maxrank_option('blog-mobile-logo', 'url')){
				$classes[] = 'has-mobile-logo';
			}
			if(maxrank_option('blog-sticky-logo', 'url')){
				$classes[] = 'has-sticky-logo';
			}
			if(maxrank_option('blog-sticky-mobile-logo', 'url')){
				$classes[] = 'has-sticky-mobile-logo';
			}
		endif;

		if (maxrank_option('logo', 'url') || function_exists('rwmb_meta') && rwmb_meta('maxrank_page_logo', 'type=image_advanced')) {
			$classes[] = 'has-site-logo';
		}
		if (maxrank_option('mobile-logo', 'url') || function_exists('rwmb_meta') && rwmb_meta('maxrank_page_mobile_logo', 'type=image_advanced')) {
			$classes[] = 'has-mobile-logo';
		}
		if (maxrank_option('sticky-logo', 'url') || function_exists('rwmb_meta') && rwmb_meta('maxrank_page_sticky_logo', 'type=image_advanced')) {
			$classes[] = 'has-sticky-logo';
		}
		if (maxrank_option('sticky-mobile-logo', 'url') || function_exists('rwmb_meta') && rwmb_meta('maxrank_page_mobile_sticky_logo', 'type=image_advanced')) {
			$classes[] = 'has-sticky-mobile-logo';
		}
		return $classes;
	}
	add_filter( 'body_class', 'maxrank_body_classes' );

endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'maxrank_page_menu_args' ) ) :

	function maxrank_page_menu_args( $args ) {

		$args[ 'show_home' ] = TRUE;

		return $args;
	}

	add_filter( 'wp_page_menu_args', 'maxrank_page_menu_args' );

endif;



//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Sets the authordata global when viewing an author archive.
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'maxrank_setup_author' ) ) :
	function maxrank_setup_author() {
		global $wp_query;

		if ( $wp_query->is_author() && isset( $wp_query->post ) ) {
			$GLOBALS[ 'authordata' ] = get_userdata( $wp_query->post->post_author );
		}
	}

	add_action( 'wp', 'maxrank_setup_author' );

endif;



//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Page break button in editor
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'maxrank_wp_page_pagination' ) ) :

	function maxrank_wp_page_pagination( $mce_buttons ) {
		if ( get_post_type() == 'post' or get_post_type() == 'page' ) {
			$pos = array_search( 'wp_more', $mce_buttons, TRUE );
			if ( $pos !== FALSE ) {
				$buttons     = array_slice( $mce_buttons, 0, $pos + 1 );
				$buttons[ ]  = 'wp_page';
				$mce_buttons = array_merge( $buttons, array_slice( $mce_buttons, $pos + 1 ) );
			}
		}

		return $mce_buttons;
	}

	add_filter( 'mce_buttons', 'maxrank_wp_page_pagination' );

endif;



//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Redux News Flash Remove 
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! class_exists( 'reduxNewsflash' ) ):
	class reduxNewsflash {
		public function __construct( $parent, $params ) {

		}
	}
endif;

//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Redux Ads Remove
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

	add_filter( 'redux/' . 'maxrank_theme_option' . '/aURL_filter', '__return_empty_string' );