<?php
if ( ! defined( 'ABSPATH' ) ) :
    exit; // Exit if accessed directly
endif;
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Register meta boxes
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if (! function_exists('maxrank_register_meta_boxes')) :

	function maxrank_register_meta_boxes( $meta_boxes ) {
		/**
		 * Prefix of meta keys (optional)
		 */

		$prefix = 'maxrank_';

		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		// Meta for post format quote
		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

		$meta_boxes[] = array(
			'id' => 'tt-post-format-quote',

			// Meta box title - Will appear at the drag and drop handle bar. Required.
			'title' => esc_html__( 'Post Quote Settings', 'maxrank' ),

			// Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
			'pages' => array( 'post'),

			// Where the meta box appear: normal (default), advanced, side. Optional.
			'context' => 'normal',

			// Order of meta box: high (default), low. Optional.
			'priority' => 'high',

			// Auto save: true, false (default). Optional.
			'autosave' => true,

			// List of meta fields
			'fields' => array(
				array(
					// Field name - Will be used as label
					'name'  => esc_html__( 'Qoute Text', 'maxrank' ),
					// Field ID, i.e. the meta key
					'id'    => "{$prefix}qoute",
					'desc'  => esc_html__( 'Write Your Qoute Here', 'maxrank' ),
					'type'  => 'textarea',
					// Default value (optional)
					'std'   => ''
				),
				array(
					// Field name - Will be used as label
					'name'  => esc_html__( 'Qoute Author/Company', 'maxrank' ),
					// Field ID, i.e. the meta key
					'id'    => "{$prefix}qoute_author",
					'desc'  => esc_html__( 'Write Qoute Author or Company name', 'maxrank' ),
					'type'  => 'text',
					// Default value (optional)
					'std'   => ''
				),
				array(
					// Field name - Will be used as label
					'name'  => esc_html__( 'Author/Company URL', 'maxrank' ),
					// Field ID, i.e. the meta key
					'id'    => "{$prefix}qoute_author_url",
					'desc'  => esc_html__( 'Write Qoute Author or Company URL', 'maxrank' ),
					'type'  => 'text',
					// Default value (optional)
					'std'   => ''
				)
			)
		);


		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		// Meta for post format link
		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		$meta_boxes[] = array(
			'id' => 'tt-post-format-link',
			'title' => esc_html__( 'Post Link Settings', 'maxrank' ),
			'pages' => array( 'post'),
			'context' => 'normal',
			'priority' => 'high',
			'autosave' => true,
			'fields' => array(
				array(
					'name'  => esc_html__( 'Link text', 'maxrank' ),
					'id'    => "{$prefix}link_text",
					'desc'  => esc_html__( 'Write Your Link Text, leave blank to show only url', 'maxrank' ),
					'type'  => 'text',
					'std'   => ''
				),

				array(
					'name'  => esc_html__( 'Link URL*', 'maxrank' ),
					'id'    => "{$prefix}link",
					'desc'  => esc_html__( 'Write Your Link, e.g: http://yourlink.com', 'maxrank' ),
					'type'  => 'text',
					'std'   => ''
				),

				array(
					'name'     => esc_html__( 'Link title', 'maxrank' ),
					'id'       => "{$prefix}link_title",
					'desc'     => esc_html__( 'Write link title, appear as link title attribute', 'maxrank' ),
					'type'     => 'text',
					'std'      => ''
				),

				array(
					'name'     => esc_html__( 'Link target', 'maxrank' ),
					'id'       => "{$prefix}link_target",
					'type'     => 'select',
					'options'  => array(
						'_self' => esc_html__( 'Self', 'maxrank' ),
						'_blank' => esc_html__( 'New Window', 'maxrank' )
					),
					'std'         => 'self'
				)
			)
		);

		
		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		// Meta for post format audio
		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		$meta_boxes[] = array(
			'id' => 'tt-post-format-audio',
			'title' => esc_html__( 'Post Audio Settings', 'maxrank' ),
			'pages' => array( 'post'),
			'context' => 'normal',
			'priority' => 'high',
			'autosave' => true,
			'fields' => array(
				array(
					'name'  => esc_html__( 'Featured Audio (.mp3)', 'maxrank' ),
					'id'    => "{$prefix}featured_mp3",
					'desc'  => esc_html__( 'Upload Audio like: your-file-name.mp3', 'maxrank' ),
					'type'  => 'file_input',
					'std'   => ''
				),

				array(
					'name'  => esc_html__( 'Featured Audio (.ogg)', 'maxrank' ),
					'id'    => "{$prefix}featured_ogg",
					'desc'  => esc_html__( 'Upload Audio like: your-file-name.ogg', 'maxrank' ),
					'type'  => 'file_input',
					'std'   => ''
				),

				array(
					'name'  => esc_html__( 'Featured Audio (.wav)', 'maxrank' ),
					'id'    => "{$prefix}featured_wav",
					'desc'  => esc_html__( 'Upload Audio like: your-file-name.wav', 'maxrank' ),
					'type'  => 'file_input',
					'std'   => ''
				),

				array(
					'name'  => esc_html__( 'Embed Audio', 'maxrank' ),
					'id'    => "{$prefix}embed_audio",
					'desc'  => esc_html__( 'Input URL for sounds, audios from Youtube, Soundcloud and all supported sites by WordPress, Supported list: http://codex.wordpress.org/Embeds', 'maxrank' ),
					'type'  => 'oembed',
					'std'   => ''
				)
			)
		);


		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		// Meta for post format video
		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		$meta_boxes[] = array(
			'id' => 'tt-post-format-video',
			'title' => esc_html__( 'Post Video Settings', 'maxrank' ),
			'pages' => array( 'post'),
			'context' => 'normal',
			'priority' => 'high',
			'autosave' => true,
			'fields' => array(
				array(
					'name'  => esc_html__( 'Featured Video (.mp4)', 'maxrank' ),
					'id'    => "{$prefix}featured_mp4",
					'desc'  => esc_html__( 'Upload Video like: your-file-name.mp4', 'maxrank' ),
					'type'  => 'file_input',
					'std'   => ''
				),

				array(
					'name'  => esc_html__( 'Featured Video (.webm)', 'maxrank' ),
					'id'    => "{$prefix}featured_webm",
					'desc'  => esc_html__( 'Upload Video like: your-file-name.webm', 'maxrank' ),
					'type'  => 'file_input',
					'std'   => ''
				),

				array(
					'name'  => esc_html__( 'Featured Video (.ogv)', 'maxrank' ),
					'id'    => "{$prefix}featured_ogv",
					'desc'  => esc_html__( 'Upload Video like: your-file-name.ogv', 'maxrank' ),
					'type'  => 'file_input',
					'std'   => ''
				),

				array(
					'name'  => esc_html__( 'Embed Video', 'maxrank' ),
					'id'    => "{$prefix}embed_video",
					'desc'  => esc_html__( 'Enter embed code here.', 'maxrank' ),
					//'type'  => 'oembed',
					'type'  => 'textarea',
					'std'   => ''
				)	
			)
		);


		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		// Meta for post format gallery
		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		$meta_boxes[] = array(
			'id' => 'tt-post-format-gallery',
			'title' => esc_html__( 'Post Gallery Settings', 'maxrank' ),
			'pages' => array( 'post'),
			'context' => 'normal',
			'priority' => 'high',
			'autosave' => true,
			'fields' => array(
				array(
					'name'             => esc_html__( 'Upload image from media library', 'maxrank' ),
					'id'               => "{$prefix}post_gallery",
					'type'             => 'image_advanced',
					'max_file_uploads' => 6,
				)			
			)
		);



		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		// Meta for portfolio
		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		$meta_boxes[] = array(
			'id' => 'portfolio-meta-settings',
			'title' => esc_html__( 'Portfolio Settings', 'maxrank' ),
			'pages' => array('tt-portfolio'),
			'context' => 'normal',
			'priority' => 'high',
			'fields' => array(
				array(
					'id'      => "{$prefix}portfolio_meta",
					'name'    => esc_html__( 'Add info about this portfolio', 'maxrank' ),
					'type'    => 'text_list',
					'desc'    => esc_html__( 'Click Add More button for set more details about portfolio.', 'maxrank' ),
					'clone' => true,
					'options' => array(
						'Label'      => esc_html__( 'Label', 'maxrank' ),
						'Value' => esc_html__( 'Value', 'maxrank' ),
					),
				),
				array(
					'name'    	=> esc_html__( 'Visit Website', 'maxrank' ),
					'id'   		=> "{$prefix}portfolio_website",
					'type'    	=> 'url',
					'desc'     	=> esc_html__( 'Enter url for visit this project', 'maxrank' ),
					
				),
			)
		);


		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		// Meta for page logo
		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		$meta_boxes[] = array(
			'id' => 'page-logo-settings',
			'title' => esc_html__( 'Page Logo Settings', 'maxrank' ),
			'pages' => array( 'page', 'tt-portfolio'),
			'context' => 'normal',
			'priority' => 'high',
			'fields' => array(

				// logo
				array(
					'name'             => esc_html__( 'Page Logo', 'maxrank' ),
					'id'               => "{$prefix}page_logo",
					'type'             => 'image_advanced',
					'max_file_uploads' => 1,
					'desc'  => esc_html__( 'This logo option only for this page, dimension: 210px &times; 50px', 'maxrank' ),
				),

				// logo sticky
				array(
					'name'             => esc_html__( 'Page sticky Logo ', 'maxrank' ),
					'id'               => "{$prefix}page_sticky_logo",
					'type'             => 'image_advanced',
					'max_file_uploads' => 1,
					'desc'  => esc_html__( 'This logo option only for this page, dimension: 210px &times; 50px', 'maxrank' ),
				),

				// mobile logo
				array(
					'name'             => esc_html__( 'Page Mobile Logo', 'maxrank' ),
					'id'               => "{$prefix}page_mobile_logo",
					'type'             => 'image_advanced',
					'max_file_uploads' => 1,
					'desc'  => esc_html__( 'This logo option only for this page, dimension: 210px &times; 50px', 'maxrank' ),
				),

				// mobile logo
				array(
					'name'             => esc_html__( 'Page Mobile Sticky Logo', 'maxrank' ),
					'id'               => "{$prefix}page_mobile_sticky_logo",
					'type'             => 'image_advanced',
					'max_file_uploads' => 1,
					'desc'  => esc_html__( 'This logo option only for this page, dimension: 210px &times; 50px', 'maxrank' ),
				)
			)
		);


		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		// Meta for page header
		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		$meta_boxes[] = array(
			'id' => 'page-meta-settings',
			'title' => esc_html__( 'Page Settings', 'maxrank' ),
			'pages' => array( 'page', 'tt-portfolio'),
			'context' => 'normal',
			'priority' => 'high',
			'fields' => array(

				// header visibility option
				array(
					'name'        => esc_html__( 'Enable/Disable Page Header', 'maxrank' ),
					'id'          => "{$prefix}page_header_visibility",
					'type'        => 'select_advanced',
					// Array of 'value' => 'Label' pairs for select box
					'options'     => array(
						'header-section-show' => esc_html__( 'Header Section Show', 'maxrank' ),
						'header-section-hide' => esc_html__( 'Header Section Hide', 'maxrank' )
					),
					// Default selected value
					'std'         => 'header-section-show',
					// Placeholder
					'placeholder' => esc_html__( 'Select header visibility option', 'maxrank' )
				),

				array(
					'name'             => esc_html__( 'Subtitle', 'maxrank' ),
					'id'               => "{$prefix}page_subtitle",
					'type'             => 'text',
					'desc'  		   => esc_html__( 'Enter page subtitle', 'maxrank' ),
				),

				// Divider
				array(
					'name'             => esc_html__( 'Divider', 'maxrank' ),
					'id'               => "{$prefix}breadcumb_divider_one",
					'type'             => 'divider'
				),

				// Section padding
				array(
					'name'             => esc_html__( 'Padding top', 'maxrank' ),
					'id'               => "{$prefix}header_padding_top",
					'type'             => 'text',
					'desc'  		   => esc_html__( 'Enter page header section top padding in px', 'maxrank' ),
				),

				array(
					'name'             => esc_html__( 'Padding bottom', 'maxrank' ),
					'id'               => "{$prefix}header_padding_bottom",
					'type'             => 'text',
					'desc'  => esc_html__( 'Enter page header section bottom padding in px', 'maxrank' ),
				),

				// Divider
				array(
					'name'             => esc_html__( 'Divider', 'maxrank' ),
					'id'               => "{$prefix}breadcumb_divider_two",
					'type'             => 'divider'
				),

				// Background image
				array(
					'name'             => esc_html__( 'Background image', 'maxrank' ),
					'id'               => "{$prefix}page_header_image",
					'type'             => 'image_advanced',
					'max_file_uploads' => 1,
					'desc'  => esc_html__( 'Upload background image, dimension: 1920px x 450px', 'maxrank' ),
				),

				// background fixed
				array(
					'name'             	=> esc_html__( 'background Fixed', 'maxrank' ),
					'id'               	=> "{$prefix}parallax_header_image",
					'type'             	=> 'radio',
					'options'     		=> array(
						'parallax_header_bg' => esc_html__( 'Enable', 'maxrank' ),
						'default_header_bg' => esc_html__( 'Disable', 'maxrank' )
					),
					'std'				=> 'default_header_bg',
					'desc'  => esc_html__( 'Select background fixed option', 'maxrank' ),
				),

				// Background overlay option
				array(
					'name'             	=> esc_html__( 'Enable background overlay color', 'maxrank' ),
					'id'               	=> "{$prefix}background_overlay",
					'type'             	=> 'radio',
					'options'     		=> array(
						'bg_overlay_enable' => esc_html__( 'Enable', 'maxrank' ),
						'bg_overlay_disable' => esc_html__( 'Disable', 'maxrank' )
					),
					'std'				=> 'bg_overlay_enable',
					'desc'  			=> esc_html__( 'Select background overlay option', 'maxrank' ),
				),

				// Background color
				array(
					'name'             	=> esc_html__( 'Background color', 'maxrank' ),
					'id'               	=> "{$prefix}page_header_color",
					'type'             	=> 'color',
					'desc'  			=> esc_html__( 'Select backgroud color if do not like to use background image', 'maxrank' ),
				),

				// title color
				array(
					'name'             => esc_html__( 'Title color', 'maxrank' ),
					'id'               => "{$prefix}header_content_color",
					'type'             => 'color',
					'desc' 			   => esc_html__( 'Select page title color if needed', 'maxrank' ),
				),

				// Divider
				array(
					'name'             => esc_html__( 'Divider', 'maxrank' ),
					'id'               => "{$prefix}breadcumb_divider_three",
					'type'             => 'divider'
				),

				// Content alignment
				array(
					'name'        => esc_html__( 'Content alignment', 'maxrank' ),
					'id'          => "{$prefix}breadcrumb_content_alignment",
					'type'        => 'select_advanced',
					// Array of 'value' => 'Label' pairs for select box
					'options'     => array(
						'text-center' => esc_html__( 'Content center', 'maxrank' ),
						'text-left' => esc_html__( 'Content left', 'maxrank' ),
						'text-right' => esc_html__( 'Content right', 'maxrank' ),
						'title-left' => esc_html__( 'Title left', 'maxrank' ),
						'title-right' => esc_html__( 'Title Right', 'maxrank' )
					),
					// Default selected value
					'std'         => 'text-center',
					// Placeholder
					'placeholder' => esc_html__( 'Select breadcrumb alignment', 'maxrank' ),
				),

				// Divider
				array(
					'name'             => esc_html__( 'Divider', 'maxrank' ),
					'id'               => "{$prefix}breadcumb_divider_four",
					'type'             => 'divider'
				),

				// Hide breadcrumb
				array(
					'name'             	=> esc_html__( 'Show/hide breadcrumb', 'maxrank' ),
					'id'               	=> "{$prefix}page_breadcrumb_show",
					'type'             	=> 'radio',
					'options'     		=> array(
						'page_breadcrumb_show' => esc_html__( 'Show', 'maxrank' ),
						'page_breadcrumb_hide' => esc_html__( 'Hide', 'maxrank' )
					),
					'std'				=> 'page_breadcrumb_hide',
					'desc'  		    => esc_html__( 'Select breadcrumb show/hide option', 'maxrank' ),
				),

				// Divider
				array(
					'name'             => esc_html__( 'Divider', 'maxrank' ),
					'id'               => "{$prefix}breadcumb_divider_five",
					'type'             => 'divider'
				),

				// Page Header Margin Bottom
				array(
					'name'             => esc_html__( 'Page Header Margin Bottom', 'maxrank' ),
					'id'               => "{$prefix}page_header_margin_bottom",
					'type'             => 'text',
					'desc'  		   => esc_html__( 'Enter margin bottom value in px', 'maxrank' ),
				)
			)
		);


		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		// Meta for header topbar
		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		$meta_boxes[] = array(
			'id' => 'page-header-topbar',
			'title' => esc_html__( 'Page Header Topbar', 'maxrank' ),
			'pages' => array( 'page', 'tt-portfolio'),
			'context' => 'side',
			'priority' => 'low',
			'fields' => array(
				array(
					'name'        => esc_html__( 'Header topbar', 'maxrank' ),
					'id'          => "{$prefix}header_topbar",
					'type'        => 'select_advanced',
					// Array of 'value' => 'Label' pairs for select box
					'options'     => array(
						'inherit-theme-option' => esc_html__( 'Inherit from theme option', 'maxrank' ),
						'header-topbar-show' => esc_html__( 'Header topbar show', 'maxrank' ),
						'header-topbar-hide' => esc_html__( 'Header topbar hide', 'maxrank' )
					),
					// Default selected value
					'std'         => 'inherit-theme-option',
					// Placeholder
					'placeholder' => esc_html__( 'Select header topbar', 'maxrank' ),
				)
			)
		);

		
		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		// Meta for page header
		//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
		$meta_boxes[] = array(
			'id' => 'page-meta-settings',
			'title' => esc_html__( 'Page Settings', 'maxrank' ),
			'pages' => array( 'page', 'tt-portfolio', 'product'),
			'context' => 'normal',
			'priority' => 'high',
			'fields' => array(

				// header visibility option
				array(
					'name'        => esc_html__( 'Enable/Disable Page Header', 'maxrank' ),
					'id'          => "{$prefix}page_header_visibility",
					'type'        => 'select_advanced',
					// Array of 'value' => 'Label' pairs for select box
					'options'     => array(
						'header-inherite-option' => esc_html__( 'Inherit from theme option', 'maxrank' ),
						'header-section-show' => esc_html__( 'Header Section Show', 'maxrank' ),
						'header-section-hide' => esc_html__( 'Header Section Hide', 'maxrank' )
					),
					// Default selected value
					'std'         => 'header-inherite-option',
					// Placeholder
					'placeholder' => esc_html__( 'Select header visibility option', 'maxrank' )
				),

				array(
					'name'             => esc_html__( 'Subtitle', 'maxrank' ),
					'id'               => "{$prefix}page_subtitle",
					'type'             => 'text',
					'desc'  		   => esc_html__( 'Enter page subtitle', 'maxrank' ),
				),

				// Divider
				array(
					'name'             => esc_html__( 'Divider', 'maxrank' ),
					'id'               => "{$prefix}breadcumb_divider_one",
					'type'             => 'divider'
				),

				// Section padding
				array(
					'name'             => esc_html__( 'Padding top', 'maxrank' ),
					'id'               => "{$prefix}header_padding_top",
					'type'             => 'text',
					'desc'  		   => esc_html__( 'Enter page header section top padding in px', 'maxrank' ),
				),

				array(
					'name'             => esc_html__( 'Padding bottom', 'maxrank' ),
					'id'               => "{$prefix}header_padding_bottom",
					'type'             => 'text',
					'desc'  => esc_html__( 'Enter page header section bottom padding in px', 'maxrank' ),
				),

				// Divider
				array(
					'name'             => esc_html__( 'Divider', 'maxrank' ),
					'id'               => "{$prefix}breadcumb_divider_two",
					'type'             => 'divider'
				),

				// Background image
				array(
					'name'             => esc_html__( 'Background image', 'maxrank' ),
					'id'               => "{$prefix}page_header_image",
					'type'             => 'image_advanced',
					'max_file_uploads' => 1,
					'desc'  => esc_html__( 'Upload background image, dimension: 1920px x 450px', 'maxrank' ),
				),

				// Background fixed
				array(
					'name'             	=> esc_html__( 'Background Fixed', 'maxrank' ),
					'id'               	=> "{$prefix}parallax_header_image",
					'type'             	=> 'radio',
					'options'     		=> array(
						'parallax_header_bg' => esc_html__( 'Enable', 'maxrank' ),
						'default_header_bg' => esc_html__( 'Disable', 'maxrank' )
					),
					'std'				=> 'default_header_bg',
					'desc'  => esc_html__( 'Select background fixed option', 'maxrank' ),
				),

				// Background overlay option
				array(
					'name'             	=> esc_html__( 'Enable background overlay color', 'maxrank' ),
					'id'               	=> "{$prefix}background_overlay",
					'type'             	=> 'radio',
					'options'     		=> array(
						'bg_overlay_enable' => esc_html__( 'Enable', 'maxrank' ),
						'bg_overlay_disable' => esc_html__( 'Disable', 'maxrank' )
					),
					'std'				=> 'bg_overlay_disable',
					'desc'  => esc_html__( 'Select background overlay option', 'maxrank' ),
				),

				// Background color
				array(
					'name'             => esc_html__( 'Background color', 'maxrank' ),
					'id'               => "{$prefix}page_header_color",
					'type'             => 'color',
					'desc'  => esc_html__( 'Select backgroud color if do not like to use background image', 'maxrank' ),
				),

				// title color
				array(
					'name'             => esc_html__( 'Title color', 'maxrank' ),
					'id'               => "{$prefix}header_content_color",
					'type'             => 'color',
					'desc'  => esc_html__( 'Select page title color if needed', 'maxrank' ),
				),

				// Divider
				array(
					'name'             => esc_html__( 'Divider', 'maxrank' ),
					'id'               => "{$prefix}breadcumb_divider_three",
					'type'             => 'divider'
				),

				// Content alignment
				array(
					'name'        => esc_html__( 'Content alignment', 'maxrank' ),
					'id'          => "{$prefix}breadcrumb_content_alignment",
					'type'        => 'select_advanced',
					// Array of 'value' => 'Label' pairs for select box
					'options'     => array(
						'text-center' => esc_html__( 'Content center', 'maxrank' ),
						'text-left' => esc_html__( 'Content left', 'maxrank' ),
						'text-right' => esc_html__( 'Content right', 'maxrank' ),
						'title-left' => esc_html__( 'Title left', 'maxrank' ),
						'title-right' => esc_html__( 'Title Right', 'maxrank' )
					),
					// Default selected value
					'std'         => 'title-left',
					// Placeholder
					'placeholder' => esc_html__( 'Select breadcrumb alignment', 'maxrank' ),
				),

				// Divider
				array(
					'name'             => esc_html__( 'Divider', 'maxrank' ),
					'id'               => "{$prefix}breadcumb_divider_four",
					'type'             => 'divider'
				),

				// Hide breadcrumb
				array(
					'name'             	=> esc_html__( 'Show/hide breadcrumb', 'maxrank' ),
					'id'               	=> "{$prefix}page_breadcrumb_show",
					'type'             	=> 'radio',
					'options'     		=> array(
						'page_breadcrumb_show' => esc_html__( 'Show', 'maxrank' ),
						'page_breadcrumb_hide' => esc_html__( 'Hide', 'maxrank' )
					),
					'std'				=> 'page_breadcrumb_show',
					'desc'  => esc_html__( 'Select breadcrumb show/hide option', 'maxrank' ),
				),

				// Divider
				array(
					'name'             => esc_html__( 'Divider', 'maxrank' ),
					'id'               => "{$prefix}breadcumb_divider_five",
					'type'             => 'divider'
				),

				// Page Header Margin Bottom
				array(
					'name'             => esc_html__( 'Page Header Margin Bottom', 'maxrank' ),
					'id'               => "{$prefix}page_header_margin_bottom",
					'type'             => 'text',
					'desc'  => esc_html__( 'Enter margin bottom value in px', 'maxrank' ),
				)
			)
		);	
		
		return $meta_boxes;
	}

	add_filter( 'rwmb_meta_boxes', 'maxrank_register_meta_boxes' );

endif;